@@ -48,9 +48,9 @@ cat("DSE curvature test B 5 ...")
 
   curvatureSS <- curvature(SSmodel, warn=FALSE)$stats
 
-# if(is.R())     tst <- c(48, 100, 0.05, 323.99227471499745, 124.74717834454975,
+# old R value   tst <- c(48, 100, 0.05, 323.99227471499745, 124.74717834454975,
 #        409.3130651286905,  157.59835625487983, 1.0000000021695887, NaN)[-9]
-# if(is.Splus()) tst <- c(48, 100, 0.05, 255.387386434704,    98.33696083718515,
+# old Splus value tst <- c(48, 100, 0.05, 255.387386434704,    98.33696083718515,
 #        322.6416248003061, 124.23321787877502, 1, 1.0000000004520695  ) [-9]
 
 # Solaris with svd:
@@ -69,11 +69,11 @@ cat("DSE curvature test B 5 ...")
 #              c(48, 100, 0.05, 323.992363637501512, 124.759997096569762, 
 #                409.313177468229242, 157.614550723359201, 1.00000000146893853)
 
-# values with R 1.2.2 and Splus 3.3 ( note Linux is different !)
-   good <- if(!is.R())   
-               c(48, 100, 0.05, 323.992363637504695, 124.759997096571936,  
-	        409.313177468233278, 157.614550723361958, 1.0000000014689332) else 
-	     if ((Sys.info()[["sysname"]] == "Linux") &
+# values with Splus 3.3 
+#                c(48, 100, 0.05, 323.992363637504695, 124.759997096571936,  
+# 	        409.313177468233278, 157.614550723361958, 1.0000000014689332) else 
+# values with R 1.2.2 ( note Linux is different !)
+   good <-   if ((Sys.info()[["sysname"]] == "Linux") &
 	         (.Machine$sizeof.pointer <=4) ) 
                c(48, 100, 0.05, 323.989506507851672, 124.76868587630355,  
 	        409.309567936195094, 157.625527624176414, 1.00000000058753002) else 
@@ -109,9 +109,9 @@ cat("DSE curvature test B 6 ...")
 
 # previous test values were suspicious
 #  if (print.values) printTestValue(curvatureARMA, digits=digits)
-# if(is.R())     tst <- c(71,100,0.05, 8.083857768891898e+23, 354675866.7879350,
+# R   tst <- c(71,100,0.05, 8.083857768891898e+23, 354675866.7879350,
 #          1.0653907038344889e+24, 467435699.82689363, 1, NaN )[-9]
-# if(is.Splus()) tst <- c(72,100,0.05, 31947799733885313024, 1708051.5249938569,
+# Splus tst <- c(72,100,0.05, 31947799733885313024, 1708051.5249938569,
 #       42274456907383595008,  2260154.101077503, 1, 1.0000267463352852 )[-9] 
 #   tst <- c(71, 100, 0.0500000000000000028, 1.48023299583791679e+23, 
 #     7.16541930125915901e+21,  1.95083401806432887e+23, 9.443475294697275e+21,   1 )
@@ -127,10 +127,10 @@ cat("DSE curvature test B 6 ...")
 # Solaris with La.svd:
 #               c(48, 100, 0.05, 149.118676845179181, 73.5365097052158205,
 #	        188.387895177827971, 92.9017650583947585, 1.00005841302234355)
-   good <- if(!is.R())   
-               c(48, 100, 0.05, 149.118676845175685, 73.5365097052148116,  
-                188.387895177823538, 92.9017650583934795, 1.00005841302234355) else 
-	     if (Sys.info()[["sysname"]] == "Linux") 
+#  Splus
+#               c(48, 100, 0.05, 149.118676845175685, 73.5365097052148116,  
+#                188.387895177823538, 92.9017650583934795, 1.00005841302234355) else 
+   good <-  if (Sys.info()[["sysname"]] == "Linux") 
                c(48, 100, 0.05, 149.059221869575282, 73.5866620776083522,
 	        188.312783206954663, 92.9651246594393541, 1.00005807705159655) else 
 	     if (Sys.info()[["sysname"]] == "SunOS" ) 
